==> haskell-microlens-ghc-0.4.13-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-ghc
version:              0.4.13
visibility:           public
id:                   microlens-ghc-0.4.13-LodxUOxXuklCV7RqLb7Fvl
key:                  microlens-ghc-0.4.13-LodxUOxXuklCV7RqLb7Fvl
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  5acaff4cea5b4e8a5a6550b841eca999
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/microlens-ghc-0.4.13
library-dirs:         /usr/lib/ghc-8.10.4/site-local/microlens-ghc-0.4.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/microlens-ghc-0.4.13
hs-libraries:         HSmicrolens-ghc-0.4.13-LodxUOxXuklCV7RqLb7Fvl
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    microlens-0.4.12.0-LWmCgM3D0eIxbRgAEzd8k transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.13.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-ghc
version:              0.4.13.2
visibility:           public
id:                   microlens-ghc-0.4.13.2-IvaTgXP3y4hAfIzgbEA0TH
key:                  microlens-ghc-0.4.13.2-IvaTgXP3y4hAfIzgbEA0TH
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  946757468ca9f52b9a31f8f0f517c746
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microlens-ghc-0.4.13.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microlens-ghc-0.4.13.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-ghc
hs-libraries:         HSmicrolens-ghc-0.4.13.2-IvaTgXP3y4hAfIzgbEA0TH
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
